@@ -1,548 +1,458 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="fr_FR">
+<!DOCTYPE TS>
+<TS version="2.0" language="es">
+<context>
+    <name></name>
+    <message>
+        <source></source>
+        <translation>Project-Id-Version: PACKAGE VERSION
+Report-Msgid-Bugs-To: 
+POT-Creation-Date: 2008-11-12 21:25+0200
+PO-Revision-Date: 2010-03-14 16:37+0000
+Last-Translator: DiegoJ &lt;diegojromerolopez@gmail.com&gt;
+Language-Team: LANGUAGE &lt;LL@li.org&gt;
+MIME-Version: 1.0
+Content-Type: text/plain; charset=UTF-8
+Content-Transfer-Encoding: 8bit
+X-Launchpad-Export-Date: 2010-04-22 14:00+0000
+X-Generator: Launchpad (build Unknown)
+</translation>
+    </message>
+</context>
 <context>
     <name>LogForm</name>
     <message>
-        <location filename="../log.cpp" line="82"/>
         <source>Date</source>
-        <translation type="unfinished"></translation>
+        <translation>Fecha</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="82"/>
         <source>Machine</source>
-        <translation type="unfinished"></translation>
+        <translation>Equipo</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="82"/>
         <source>User</source>
-        <translation type="unfinished"></translation>
+        <translation>Usuario</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="82"/>
         <source>Service</source>
-        <translation type="unfinished"></translation>
+        <translation>Servicio</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="108"/>
-        <source>Open File</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../log.cpp" line="82"/>
         <source>Type</source>
-        <translation type="unfinished"></translation>
+        <translation>Tipo</translation>
+    </message>
+    <message>
+        <source>Open File</source>
+        <translation>Abrir archivo</translation>
     </message>
 </context>
 <context>
     <name>MainWindows</name>
     <message>
-        <location filename="../mainwindows.cpp" line="86"/>
         <source>Show CIFS/SMB activities</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="88"/>
         <source>Configure</source>
-        <translation type="unfinished"></translation>
+        <translation>Configurar</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="172"/>
         <source>Minimize</source>
-        <translation type="unfinished"></translation>
+        <translation>Minimizar</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="93"/>
         <source>Quit</source>
-        <translation type="unfinished"></translation>
+        <translation>Salir</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="170"/>
         <source>Restore</source>
-        <translation type="unfinished"></translation>
+        <translation>Restaurar</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="245"/>
         <source>Thanks to:</source>
-        <translation type="unfinished"></translation>
+        <translation>Gracias a:</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="259"/>
         <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
         <translation>Este programa esta licenciado a usted bajo los terminos de la Licencia General Publica GNU version 2</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="291"/>
         <source>Find text</source>
-        <translation type="unfinished"></translation>
+        <translation>Buscar texto</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="342"/>
         <source>Text not found.</source>
-        <translation type="unfinished"></translation>
+        <translation>Texto no encontrado.</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="380"/>
         <source>User %1 has opened share %2 (%3)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="381"/>
         <source>User %1 has opened file %2 (%3)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="392"/>
         <source>CIFS/SMB activities</source>
-        <translation type="unfinished"></translation>
+        <translation>Actividades CIFS/SMB</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="504"/>
         <source>Message to send</source>
-        <translation type="unfinished"></translation>
+        <translation>Mensaje a enviar</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="532"/>
         <source>Message to send to %1:</source>
-        <translation type="unfinished"></translation>
+        <translation>Mensaje para enviar a %1:</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="563"/>
         <source>Do you really want to disconnect user %1 ?</source>
-        <translation type="unfinished"></translation>
+        <translation>¿Desea realmente desconectar al usuario %1?</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="564"/>
         <source>&amp;Yes</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Si</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="564"/>
         <source>&amp;No</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;No</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="618"/>
         <source>Properties</source>
-        <translation type="unfinished"></translation>
+        <translation>Propiedades</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="592"/>
         <source>Send out message to all users</source>
-        <translation type="unfinished"></translation>
+        <translation>Mandar mensajes a todos los usuarios</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="602"/>
         <source>Send out message to</source>
-        <translation type="unfinished"></translation>
+        <translation>enviar mensaje a</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="612"/>
         <source>Disconnect user</source>
-        <translation type="unfinished"></translation>
+        <translation>Desconectar usuario</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="720"/>
         <source>Update is available</source>
-        <translation type="unfinished"></translation>
+        <translation>La actualización está disponible</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="723"/>
         <source>A new release of %1 is available</source>
-        <translation type="unfinished"></translation>
+        <translation>Una nueva versión de %1 está disponible</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="725"/>
         <source>You can download it here: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Puede descargarlo desde aquí: %1</translation>
     </message>
 </context>
 <context>
     <name>configure</name>
     <message>
-        <location filename="../configure.ui" line="19"/>
         <source>Configure</source>
-        <translation type="unfinished"></translation>
+        <translation>Configurar</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="345"/>
-        <source>Username (default :  username = root)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../configure.ui" line="325"/>
-        <source>Autoconnect</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../configure.ui" line="332"/>
-        <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../configure.ui" line="309"/>
-        <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../configure.ui" line="355"/>
-        <source>Host Address</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../configure.ui" line="62"/>
-        <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../configure.ui" line="238"/>
-        <source>Cancel</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../configure.ui" line="215"/>
-        <source>OK</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../configure.ui" line="190"/>
-        <source>Log SMB/CIFS activities</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../configure.ui" line="180"/>
-        <source>Status notification messages</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../configure.ui" line="107"/>
-        <source>Notifications and log</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../configure.ui" line="125"/>
-        <source>Limit log:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../configure.ui" line="154"/>
-        <source>days</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../configure.ui" line="170"/>
-        <source>Iconize QtSmbstatus in system tray</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../configure.ui" line="31"/>
         <source>Smbstatus</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="75"/>
+        <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
+        <translation>&lt;p align=&quot;right&quot;&gt;Intervalo:&lt;/p&gt;</translation>
+    </message>
+    <message>
         <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="88"/>
         <source>Show hidden shares (share$)</source>
-        <translation type="unfinished"></translation>
+        <translation>Mostrar compartidos ocultos (compartido$)</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="91"/>
         <source>Show hidden shares</source>
-        <translation type="unfinished"></translation>
+        <translation>Mostrar compartidos ocultos</translation>
+    </message>
+    <message>
+        <source>Notifications and log</source>
+        <translation>Notificaciones y registro</translation>
+    </message>
+    <message>
+        <source>Limit log:</source>
+        <translation>Limitar registro:</translation>
+    </message>
+    <message>
+        <source>days</source>
+        <translation>dias</translation>
+    </message>
+    <message>
+        <source>Iconize QtSmbstatus in system tray</source>
+        <translation>Iconizar QtSmbstatus en el área de notificación</translation>
+    </message>
+    <message>
+        <source>Show activities in &quot;balloon messages&quot;</source>
+        <translation>Mostrar las actividades en &quot;Mensajes de globo&quot;</translation>
+    </message>
+    <message>
+        <source>Status notification messages</source>
+        <translation>Estado de los mensajes de notificación</translation>
+    </message>
+    <message>
+        <source>Log SMB/CIFS activities</source>
+        <translation>Registrar actividades SMB/CIFS</translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation>OK</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Cancelar</translation>
+    </message>
+    <message>
+        <source>Misc</source>
+        <translation>Varios</translation>
+    </message>
+    <message>
+        <source>Automatically Check for updates</source>
+        <translation>Revisar automaticamente por actualizaciones</translation>
+    </message>
+    <message>
+        <source>A new release is available</source>
+        <translation>Una nueva versión esta disponible</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="291"/>
         <source>Connection</source>
-        <translation type="unfinished"></translation>
+        <translation>Conexión</translation>
+    </message>
+    <message>
+        <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
+        <translation>&lt;p align=&quot;right&quot;&gt;Nombre de usuario por defecto:&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="322"/>
         <source>Autoconnect on qtsmbstatus startup</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="177"/>
-        <source>Show activities in &quot;balloon messages&quot;</source>
-        <translation type="unfinished"></translation>
+        <source>Autoconnect</source>
+        <translation>Autoconectar</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="256"/>
-        <source>Misc</source>
-        <translation type="unfinished"></translation>
+        <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
+        <translation>&lt;p align=&quot;right&quot;&gt;Dirección de host predeterminada:&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="265"/>
-        <source>Automatically Check for updates</source>
-        <translation type="unfinished"></translation>
+        <source>Username (default :  username = root)</source>
+        <translation>Usuario(defecto : usuario = root)</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="272"/>
-        <source>A new release is available</source>
-        <translation type="unfinished"></translation>
+        <source>Host Address</source>
+        <translation>Dirección del equipo</translation>
     </message>
 </context>
 <context>
     <name>form_smbstatus</name>
     <message>
-        <location filename="../form_smbstatus.ui" line="13"/>
         <source>qtsmbstatus</source>
-        <translation type="unfinished"></translation>
+        <translation>qtsmbstatus</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="117"/>
-        <source>Connect/Disconnect</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../form_smbstatus.ui" line="61"/>
         <source>Host:</source>
-        <translation type="unfinished"></translation>
+        <translation>Servidor:</translation>
+    </message>
+    <message>
+        <source>Connect/Disconnect</source>
+        <translation>Conectar/Desconectar</translation>
+    </message>
+    <message>
+        <source>&amp;File</source>
+        <translation>&amp;Archivo</translation>
+    </message>
+    <message>
+        <source>&amp;Search</source>
+        <translation>Bu&amp;scar</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="167"/>
         <source>&amp;Help</source>
-        <translation type="unfinished"></translation>
+        <translation>Ay&amp;uda</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="188"/>
         <source>&amp;About QtSmbstatus</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="205"/>
+        <source>About QtSmbstatus</source>
+        <translation>Acerca de QtSmbstatus</translation>
+    </message>
+    <message>
         <source>About &amp;Qt</source>
-        <translation type="unfinished"></translation>
+        <translation>Acerca de &amp;Qt</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="223"/>
-        <source>&amp;Configure client</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../form_smbstatus.ui" line="159"/>
-        <source>&amp;Search</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../form_smbstatus.ui" line="234"/>
-        <source>&amp;Machine</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../form_smbstatus.ui" line="245"/>
-        <source>&amp;User</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../form_smbstatus.ui" line="256"/>
-        <source>Share &amp;open</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../form_smbstatus.ui" line="267"/>
-        <source>&amp;Locked file</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../form_smbstatus.ui" line="278"/>
-        <source>&amp;Next</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../form_smbstatus.ui" line="284"/>
-        <source>F3</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../form_smbstatus.ui" line="292"/>
-        <source>&amp;Find text</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../form_smbstatus.ui" line="298"/>
-        <source>F5</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../form_smbstatus.ui" line="148"/>
-        <source>&amp;File</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../form_smbstatus.ui" line="208"/>
         <source>About Qt</source>
-        <translation type="unfinished"></translation>
+        <translation>Acerca de Qt</translation>
+    </message>
+    <message>
+        <source>&amp;Configure client</source>
+        <translation>&amp;Configurar cliente</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="226"/>
         <source>Configure QtSmbstatus client</source>
-        <translation type="unfinished"></translation>
+        <translation>Configurar el cliente de QtSmbstatus</translation>
+    </message>
+    <message>
+        <source>&amp;Machine</source>
+        <translation>&amp;Maquina</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="237"/>
         <source>Search machine</source>
-        <translation type="unfinished"></translation>
+        <translation>Buscar Maquina</translation>
+    </message>
+    <message>
+        <source>&amp;User</source>
+        <translation>&amp;Usuario</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="248"/>
         <source>Search user</source>
-        <translation type="unfinished"></translation>
+        <translation>Buscar usuario</translation>
+    </message>
+    <message>
+        <source>Share &amp;open</source>
+        <translation>Compartir &amp;abierto</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="259"/>
         <source>Search share open</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="270"/>
+        <source>&amp;Locked file</source>
+        <translation>Archivo b&amp;loqueado</translation>
+    </message>
+    <message>
         <source>Search file open</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="281"/>
+        <source>&amp;Next</source>
+        <translation>Siguie&amp;nte</translation>
+    </message>
+    <message>
         <source>Next</source>
-        <translation type="unfinished"></translation>
+        <translation>Siguiente</translation>
+    </message>
+    <message>
+        <source>F3</source>
+        <translation>F3</translation>
+    </message>
+    <message>
+        <source>&amp;Find text</source>
+        <translation>&amp;Buscar texto</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="295"/>
         <source>Find text</source>
-        <translation type="unfinished"></translation>
+        <translation>Buscar texto</translation>
+    </message>
+    <message>
+        <source>F5</source>
+        <translation>F5</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="307"/>
         <source>&amp;Quit</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Salir</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="310"/>
         <source>Quit QtSmbstatus</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="324"/>
-        <source>Co&amp;nnect</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../form_smbstatus.ui" line="315"/>
         <source>&amp;Show CIFS/SMB activities</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="191"/>
-        <source>About QtSmbstatus</source>
-        <translation type="unfinished"></translation>
+        <source>Co&amp;nnect</source>
+        <translation>Co&amp;nectar</translation>
     </message>
 </context>
 <context>
     <name>logform</name>
     <message>
-        <location filename="../log.ui" line="13"/>
         <source>View Activities</source>
-        <translation type="unfinished"></translation>
+        <translation>Ver Actividades</translation>
     </message>
     <message>
-        <location filename="../log.ui" line="124"/>
-        <source>View/hide shares</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../log.ui" line="156"/>
-        <source>View/hide files</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../log.ui" line="196"/>
-        <source>Filter:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../log.ui" line="41"/>
         <source>Clear</source>
-        <translation type="unfinished"></translation>
+        <translation>Limpiar</translation>
     </message>
     <message>
-        <location filename="../log.ui" line="104"/>
-        <source>Close</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../log.ui" line="70"/>
         <source>Save log</source>
-        <translation type="unfinished"></translation>
+        <translation>Guardar registro</translation>
+    </message>
+    <message>
+        <source>Close</source>
+        <translation>Cerrar</translation>
+    </message>
+    <message>
+        <source>View/hide shares</source>
+        <translation>Ver/ocultar partes</translation>
+    </message>
+    <message>
+        <source>View/hide files</source>
+        <translation>Ver/ocultar archivos</translation>
+    </message>
+    <message>
+        <source>Filter:</source>
+        <translation>Filtro:</translation>
     </message>
 </context>
 <context>
     <name>login_dialog</name>
     <message>
-        <location filename="../login_dialog.ui" line="120"/>
+        <source>Connect to qtsmbstatus server</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Username</source>
+        <translation>Nombre de usuario</translation>
+    </message>
+    <message>
+        <source>root</source>
+        <translation>superusuario</translation>
+    </message>
+    <message>
+        <source>Password</source>
+        <translation>Contraseña</translation>
+    </message>
+    <message>
         <source>login</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="149"/>
         <source>exit</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../login_dialog.ui" line="27"/>
-        <source>Username</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../login_dialog.ui" line="49"/>
-        <source>root</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../login_dialog.ui" line="62"/>
-        <source>Password</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../login_dialog.ui" line="13"/>
-        <source>Connect to qtsmbstatus server</source>
-        <translation type="unfinished"></translation>
+        <translation>salir</translation>
     </message>
 </context>
 <context>
     <name>main_windows</name>
     <message>
-        <location filename="../main_windows.cpp" line="533"/>
-        <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
-        <translation type="obsolete">Este programa esta licenciado a usted bajo los terminos de la Licencia General Publica GNU version 2</translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="310"/>
         <source>Connect</source>
-        <translation type="unfinished"></translation>
+        <translation>Conectar</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="305"/>
-        <source>Disconnect</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="356"/>
-        <source>Invalid login or password !</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../main_windows.cpp" line="198"/>
         <source>Connection in progress on %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Conexión en progreso en %1</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="223"/>
         <source>Connected to host</source>
-        <translation type="unfinished"></translation>
+        <translation>Conectar al servidor</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="241"/>
         <source>Connection closed</source>
+        <translation>Conección cerrada</translation>
+    </message>
+    <message>
+        <source>Disconnect</source>
+        <translation>Desconectar</translation>
+    </message>
+    <message>
+        <source>Invalid login or password !</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
