@@ -1,34 +1,29 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="ru">
+<!DOCTYPE TS>
+<TS version="2.0" language="ru">
 <context>
     <name>LogForm</name>
     <message>
-        <location filename="../log.cpp" line="82"/>
         <source>Date</source>
         <translation>Дата</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="82"/>
         <source>Machine</source>
         <translation>Компьютер</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="82"/>
         <source>User</source>
         <translation>Пользователь</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="82"/>
         <source>Service</source>
         <translation>Сервис</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="82"/>
         <source>Type</source>
         <translation>Тип</translation>
     </message>
     <message>
-        <location filename="../log.cpp" line="108"/>
         <source>Open File</source>
         <translation>Открытие файла</translation>
     </message>
@@ -36,122 +31,98 @@
 <context>
     <name>MainWindows</name>
     <message>
-        <location filename="../mainwindows.cpp" line="86"/>
         <source>Show CIFS/SMB activities</source>
         <translation>Показать активность SMB/CIFS</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="88"/>
         <source>Configure</source>
         <translation>Настройка</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="172"/>
         <source>Minimize</source>
         <translation>Минимизировать</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="93"/>
         <source>Quit</source>
         <translation>Выход</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="170"/>
         <source>Restore</source>
         <translation>Восстановить</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="245"/>
         <source>Thanks to:</source>
         <translation>Благодарности:</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="259"/>
         <source>This program is licensed to you under the terms of the GNU General Public License version 2</source>
         <translation>Эта программа распространяется под лицензией GNU General Public License версии 2</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="291"/>
         <source>Find text</source>
         <translation>Найти текст</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="342"/>
         <source>Text not found.</source>
         <translation>Текст не найден.</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="380"/>
         <source>User %1 has opened share %2 (%3)</source>
         <translation>Пользователь %1 открыл ресурс %2 (%3)</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="381"/>
         <source>User %1 has opened file %2 (%3)</source>
         <translation>Пользователь %1 открыл файл %2 (%3)</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="392"/>
         <source>CIFS/SMB activities</source>
         <translation>Активность SMB/CIFS</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="504"/>
         <source>Message to send</source>
         <translation>Сообщение</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="532"/>
         <source>Message to send to %1:</source>
         <translation>Сообщение для %1:</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="563"/>
         <source>Do you really want to disconnect user %1 ?</source>
         <translation>Вы хотите отсоединить пользователя %1 ?</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="564"/>
         <source>&amp;Yes</source>
         <translation>&amp;Да</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="564"/>
         <source>&amp;No</source>
         <translation>&amp;Нет</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="618"/>
         <source>Properties</source>
         <translation>Свойства</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="592"/>
         <source>Send out message to all users</source>
         <translation>Сообщение всем пользователям</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="602"/>
         <source>Send out message to</source>
         <translation>Сообщение для</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="612"/>
         <source>Disconnect user</source>
         <translation>Отсоединить пользователя</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="720"/>
         <source>Update is available</source>
         <translation>Доступно обновление</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="723"/>
         <source>A new release of %1 is available</source>
         <translation>Доступен новый релиз %1</translation>
     </message>
     <message>
-        <location filename="../mainwindows.cpp" line="725"/>
         <source>You can download it here: %1</source>
         <translation>Вы можете загрузить здесь: %1</translation>
     </message>
@@ -159,127 +130,102 @@
 <context>
     <name>configure</name>
     <message>
-        <location filename="../configure.ui" line="19"/>
         <source>Configure</source>
         <translation>Настройка</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="107"/>
         <source>Notifications and log</source>
         <translation>Уведомления и отчет</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="125"/>
         <source>Limit log:</source>
         <translation>Лимит отчета:</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="154"/>
         <source>days</source>
         <translation>дней</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="170"/>
         <source>Iconize QtSmbstatus in system tray</source>
         <translation>Иконка QtSmbstatus в лотке</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="177"/>
         <source>Show activities in &quot;balloon messages&quot;</source>
         <translation>Активность в &quot;плавающих сообщениях&quot;</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="180"/>
         <source>Status notification messages</source>
         <translation>Уведомление статуса</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="190"/>
         <source>Log SMB/CIFS activities</source>
         <translation>Отчет активности SMB/CIFS</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="31"/>
         <source>Smbstatus</source>
         <translation>Smbstatus</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="62"/>
         <source>&lt;p align=&quot;right&quot;&gt;Interval:&lt;/p&gt;</source>
         <translation>&lt;p align=&quot;right&quot;&gt;Интервал:&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="75"/>
         <source>Interval between smbstatus requests in seconds, (interval &gt; 2)</source>
         <translation>Интервал между запросами smbstatus в секундах (интервал &gt; 2)</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="88"/>
         <source>Show hidden shares (share$)</source>
         <translation>Показать скрытые ресурсы (share$)</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="91"/>
         <source>Show hidden shares</source>
         <translation>Показать скрытые ресурсы</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="291"/>
         <source>Connection</source>
         <translation>Соединение</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="309"/>
         <source>&lt;p align=&quot;right&quot;&gt;Default Username:&lt;/p&gt;</source>
         <translation>&lt;p align=&quot;right&quot;&gt;Пользователь по умолчанию:&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="322"/>
         <source>Autoconnect on qtsmbstatus startup</source>
         <translation>Автоконнект при старте qtsmbstatus</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="325"/>
         <source>Autoconnect</source>
         <translation>Автоконнект</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="332"/>
         <source>&lt;p align=&quot;right&quot;&gt;Default host address:&lt;/p&gt;</source>
         <translation>&lt;p align=&quot;right&quot;&gt;Хост по умолчанию:&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="345"/>
         <source>Username (default :  username = root)</source>
         <translation>Пользователь (по умолчанию :  пользователь = root)</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="355"/>
         <source>Host Address</source>
         <translation>Адрес хоста</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="215"/>
         <source>OK</source>
         <translation>ДА</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="238"/>
         <source>Cancel</source>
         <translation>Отмена</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="256"/>
         <source>Misc</source>
         <translation>Разное</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="265"/>
         <source>Automatically Check for updates</source>
         <translation>Автоматически проверять обновления</translation>
     </message>
     <message>
-        <location filename="../configure.ui" line="272"/>
         <source>A new release is available</source>
         <translation>Доступен новый релиз</translation>
     </message>
@@ -287,152 +233,122 @@
 <context>
     <name>form_smbstatus</name>
     <message>
-        <location filename="../form_smbstatus.ui" line="13"/>
         <source>qtsmbstatus</source>
         <translation>qtsmbstatus</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="117"/>
         <source>Connect/Disconnect</source>
         <translation>Коннект/Дисконнект</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="61"/>
         <source>Host:</source>
         <translation>Хост:</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="148"/>
         <source>&amp;File</source>
         <translation>&amp;Файл</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="159"/>
         <source>&amp;Search</source>
         <translation>&amp;Поиск</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="167"/>
         <source>&amp;Help</source>
         <translation>&amp;Справка</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="188"/>
         <source>&amp;About QtSmbstatus</source>
         <translation>&amp;О QtSmbstatus</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="191"/>
         <source>About QtSmbstatus</source>
         <translation>О QtSmbstatus</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="205"/>
         <source>About &amp;Qt</source>
         <translation>О &amp;Qt</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="208"/>
         <source>About Qt</source>
         <translation>О Qt</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="223"/>
         <source>&amp;Configure client</source>
         <translation>&amp;Конфигурация клиента</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="226"/>
         <source>Configure QtSmbstatus client</source>
         <translation>Конфигурация QtSmbstatus клиента</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="234"/>
         <source>&amp;Machine</source>
         <translation>&amp;Компьютер</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="237"/>
         <source>Search machine</source>
         <translation>Поиск компьютера</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="245"/>
         <source>&amp;User</source>
         <translation>&amp;Пользователь</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="248"/>
         <source>Search user</source>
         <translation>Поиск пользователя</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="256"/>
         <source>Share &amp;open</source>
         <translation>&amp;Открытые ресурсы</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="259"/>
         <source>Search share open</source>
         <translation>Поиск открытых ресурсов</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="267"/>
         <source>&amp;Locked file</source>
         <translation>&amp;Блокированные файлы</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="270"/>
         <source>Search file open</source>
         <translation>Поиск открытых файлов</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="278"/>
         <source>&amp;Next</source>
         <translation>&amp;Дальше</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="281"/>
         <source>Next</source>
         <translation>Дальше</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="284"/>
         <source>F3</source>
         <translation>F3</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="292"/>
         <source>&amp;Find text</source>
         <translation>&amp;Найти текст</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="295"/>
         <source>Find text</source>
         <translation>Найти текст</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="298"/>
         <source>F5</source>
         <translation>F5</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="307"/>
         <source>&amp;Quit</source>
         <translation>&amp;Выход</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="310"/>
         <source>Quit QtSmbstatus</source>
         <translation>Выйти из QtSmbstatus</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="315"/>
         <source>&amp;Show CIFS/SMB activities</source>
         <translation>&amp;Показать активность SMB/CIFS</translation>
     </message>
     <message>
-        <location filename="../form_smbstatus.ui" line="324"/>
         <source>Co&amp;nnect</source>
         <translation>Со&amp;единение</translation>
     </message>
@@ -440,37 +356,30 @@
 <context>
     <name>logform</name>
     <message>
-        <location filename="../log.ui" line="13"/>
         <source>View Activities</source>
         <translation>Смотреть активность</translation>
     </message>
     <message>
-        <location filename="../log.ui" line="41"/>
         <source>Clear</source>
         <translation>Очистить</translation>
     </message>
     <message>
-        <location filename="../log.ui" line="70"/>
         <source>Save log</source>
         <translation>Сохранить отчет</translation>
     </message>
     <message>
-        <location filename="../log.ui" line="104"/>
         <source>Close</source>
         <translation>Закрыть</translation>
     </message>
     <message>
-        <location filename="../log.ui" line="124"/>
         <source>View/hide shares</source>
         <translation>Показать/скрыть ресурсы</translation>
     </message>
     <message>
-        <location filename="../log.ui" line="156"/>
         <source>View/hide files</source>
         <translation>Показать/скрыть файлы</translation>
     </message>
     <message>
-        <location filename="../log.ui" line="196"/>
         <source>Filter:</source>
         <translation>Фильтр:</translation>
     </message>
@@ -478,32 +387,26 @@
 <context>
     <name>login_dialog</name>
     <message>
-        <location filename="../login_dialog.ui" line="13"/>
         <source>Connect to qtsmbstatus server</source>
         <translation>Соединение с сервером qtsmbstatus</translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="27"/>
         <source>Username</source>
         <translation>Пользователь</translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="120"/>
         <source>login</source>
         <translation>логин</translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="149"/>
         <source>exit</source>
         <translation>выход</translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="49"/>
         <source>root</source>
         <translation>root</translation>
     </message>
     <message>
-        <location filename="../login_dialog.ui" line="62"/>
         <source>Password</source>
         <translation>Пароль</translation>
     </message>
@@ -511,32 +414,26 @@
 <context>
     <name>main_windows</name>
     <message>
-        <location filename="../main_windows.cpp" line="310"/>
         <source>Connect</source>
         <translation>Соединение</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="305"/>
         <source>Disconnect</source>
         <translation>Дисконнект</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="356"/>
         <source>Invalid login or password !</source>
         <translation>Неправильный логин или пароль!</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="198"/>
         <source>Connection in progress on %1</source>
         <translation>Процесс соединения на %1</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="223"/>
         <source>Connected to host</source>
         <translation>Соединено с хостом</translation>
     </message>
     <message>
-        <location filename="../main_windows.cpp" line="241"/>
         <source>Connection closed</source>
         <translation>Соединение закрыто</translation>
     </message>
